# NLP Applications

## Typical Vector Model Uses

  - clustering
    - cosine distance, manhattan distance best
  - translation
  - matching
  - labeling/tagging
  - sentiment analysis
  - predicting anything
  - generating new text 

## Applications

- News reporting
  - sports
  - financial
- News "sourcing" (Banjo)
- Searching
  - semantic search
- Matching (resumes-jobs)
- Chat bot
  - Turing test
  - Video game behavior modification
  - AI characters
    - Witcher
    - Star Citizen
- Automated Forum Curation
  - monitoring
  - automated dispute defusing
- Linguistic Forensics
  - Who wrote Shakespear's plays?
  - How many women published under male pseudonyms in 18th century?


